ISteamNetworkingMessages

Struct ISteamNetworkingMessages 

#[repr(C)]
pub struct ISteamNetworkingMessages { pub vtable_: *const ISteamNetworkingMessages__bindgen_vtable, }
The non-connection-oriented interface to send and receive messages (whether they be “clients” or “servers”).

ISteamNetworkingSockets is connection-oriented (like TCP), meaning you need to listen and connect, and then you send messages using a connection handle. ISteamNetworkingMessages is more like UDP, in that you can just send messages to arbitrary peers at any time. The underlying connections are established implicitly.

Under the hood ISteamNetworkingMessages works on top of the ISteamNetworkingSockets code, so you get the same routing and messaging efficiency. The difference is mainly in your responsibility to explicitly establish a connection and the type of feedback you get about the state of the connection. Both interfaces can do “P2P” communications, and both support both unreliable and reliable messages, fragmentation and reassembly.

The primary purpose of this interface is to be “like UDP”, so that UDP-based code can be ported easily to take advantage of relayed connections. If you find yourself needing more low level information or control, or to be able to better handle failure, then you probably need to use ISteamNetworkingSockets directly. Also, note that if your main goal is to obtain a connection between two peers without concerning yourself with assigning roles of “client” and “server”, you may find the symmetric connection mode of ISteamNetworkingSockets useful. (See k_ESteamNetworkingConfig_SymmetricConnect.)

Fields

vtable_: *const ISteamNetworkingMessages__bindgen_vtable